﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace XamComboEditor_sample.ViewModel
{
    public class Item : INotifyPropertyChanged
    {
        private string name;
        private string oldName;
        private int id;
        private double weight;

        public Item(string name, int id, double weight)
        {
            this.Name = name;
            this.OldName = null;
            this.Id = id;
            this.Weight = weight;
        }

        public string Name
        {
            get { return name; }
            set
            {
                if (value != name)
                {
                    OldName = name;
                    name = value;
                }
                NotifyPropertyChanged("Name");
            }
        }

        public string OldName
        {
            get { return oldName; }
            set
            {
                // Set OldName only if it is not currently set or it should be reset.
                // This way only its first set is kept prior to the reset.
                if (oldName == null || (oldName != null && value == null))
                    oldName = value;
                NotifyPropertyChanged("OldName");
            }
        }

        public int Id
        {
            get { return id; }
            set
            {
                id = value;
                NotifyPropertyChanged("Id");
            }
        }

        public double Weight
        {
            get { return weight; }
            set
            {
                weight = value;
                NotifyPropertyChanged("Weight");
            }
        }

        #region Notify Property Changed

        public event PropertyChangedEventHandler PropertyChanged;
        private void NotifyPropertyChanged(string propertyName = "")
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion // Notify Property Changed 

    }
}
